@@ -9,6 +9,7 @@ import os
 from pprint import pformat
 
 from typing import List
+from typing import Dict
 
 from baseblock import FileIO
 from baseblock import Enforcer
@@ -30,7 +31,7 @@ class SchemaOrchestrator(BaseObject):
     """
 
     def __init__(self,
-                 schema_file: str):
+                 d_schema: Dict):
         """Initialize Portendo API
 
         Created:
@@ -57,19 +58,17 @@ class SchemaOrchestrator(BaseObject):
                 https://bast-ai.atlassian.net/browse/COR-12
             *   document the schema-file to schema-name mapping convention
                 https://bast-ai.atlassian.net/browse/COR-13
+        Updated:
+            26-Sept-2022
+            craigtrim@gmail.com
+            *   pass in d-schema as dict rather than a filepath
+                https://github.com/craigtrim/schema-classification/issues/1
 
         Args:
-            schema_file (str): the absolute path to a local schema file containing classification rules
+            d_schema (Dict): the schema JSON
         """
         BaseObject.__init__(self, __name__)
-        if self.isEnabledForDebug:
-            Enforcer.is_str(schema_file)
-            FileIO.exists_or_error(schema_file)
-
-        self._schema_name = os.path.basename(
-            schema_file).split('-')[0].strip()  # COR-13
-
-        self._d_index = ReadMapping(schema_file).index()
+        self._d_index = ReadMapping(d_schema).index()
 
     def _run(self,
              input_tokens: List[str]) -> ServiceEvent:
@@ -82,9 +81,7 @@ class SchemaOrchestrator(BaseObject):
             'input': input_tokens
         }
 
-        mapping_result_dict = PredictMapping(
-            d_index=self._d_index,
-            ontology_name=self._schema_name).process(svcresult)
+        mapping_result_dict = PredictMapping(self._d_index).process(svcresult)
 
         mapping = SelectMapping(
             results=mapping_result_dict,
