@@ -9,7 +9,7 @@ from pprint import pformat
 from collections import Counter
 
 from typing import Dict
-from typing import Counter
+# from typing import Counter
 
 from baseblock import Stopwatch
 from baseblock import BaseObject
