@@ -1,11 +1,13 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
+# type: ignore[import]
+# type: ignore[func-returns-value]
 """Load the Mapping File for a given Test Case"""
 
 
 import os
+from typing import Dict
 
-from baseblock import EnvIO
 from baseblock import FileIO
 from baseblock import BaseObject
 
@@ -23,7 +25,7 @@ class FileLoaderMapping(BaseObject):
         BaseObject.__init__(self, __name__)
 
     def process(self,
-                test_case: dict) -> dict:
+                test_case: Dict) -> dict:
         """ Load Mapping """
 
         # mapping defined within the test case
