@@ -1,9 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
+# type: ignore[import]
+# type: ignore[func-returns-value]
 """ Generate an Index of 'score' Mappings """
 
 
-from collections import defaultdict
+from typing import Dict
+
 
 from baseblock import Stopwatch
 from baseblock import BaseObject
@@ -13,7 +16,7 @@ class IndexScoring(BaseObject):
     """ Generate an Index of 'score' Mappings """
 
     def __init__(self,
-                 mapping: dict):
+                 mapping: Dict):
         """ Change Log
 
         Created:
@@ -30,9 +33,9 @@ class IndexScoring(BaseObject):
         BaseObject.__init__(self, __name__)
         self._mapping = mapping
 
-    def process(self) -> dict:
+    def process(self) -> Dict:
         sw = Stopwatch()
-        d = defaultdict(list)
+        d = {}
 
         for k in self._mapping:
             for mapping in self._mapping[k]:
@@ -50,4 +53,4 @@ class IndexScoring(BaseObject):
                 f"\tTotal Rows: {len(d)}",
                 f"\tTotal Time: {str(sw)}"]))
 
-        return dict(d)
+        return d
