@@ -1,8 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
+# type: ignore[import]
+# type: ignore[func-returns-value]
 """ Generate an Index of 'startswith' Mappings"""
 
 
+from typing import Dict
+
 from collections import defaultdict
 
 from baseblock import Stopwatch
@@ -13,7 +17,7 @@ class IndexStartsWith(BaseObject):
     """ Generate an Index of 'startswith' Mappings"""
 
     def __init__(self,
-                 mapping: dict):
+                 mapping: Dict):
         """ Change Log
 
         Created:
@@ -30,7 +34,7 @@ class IndexStartsWith(BaseObject):
         BaseObject.__init__(self, __name__)
         self._mapping = mapping
 
-    def process(self) -> dict:
+    def process(self) -> Dict:
         sw = Stopwatch()
         d = defaultdict(list)
 
@@ -38,7 +42,7 @@ class IndexStartsWith(BaseObject):
             for mapping in self._mapping[k]:
                 if 'startswith' in mapping:
                     for marker_name in mapping['startswith']:
-                        d[marker_name].append(k)
+                        d[str(marker_name)].append(str(k))
 
         if self.isEnabledForDebug:
             self.logger.debug('\n'.join([
