@@ -31,7 +31,6 @@ class PredictMapping(BaseObject):
     """Predict a Mapping"""
 
     def __init__(self,
-                 ontology_name: str,
                  d_index: NormalizedSchema):
         """ Initialize Service
 
@@ -46,14 +45,9 @@ class PredictMapping(BaseObject):
                 https://github.com/grafflr/deepnlu/issues/45
 
         Args:
-            ontology_name (str):
             d_index (dict): the indexed schema
         """
         BaseObject.__init__(self, __name__)
-        if self.isEnabledForDebug:
-            self.logger.debug('\n'.join([
-                "Initialized Service",
-                f"\tOntology Name: {ontology_name}"]))
 
         self._include_one_of = ComputerIncludeOneOf(d_index).process
         self._include_all_of = ComputerIncludeAllOf(d_index).process
@@ -63,9 +57,6 @@ class PredictMapping(BaseObject):
 
     def _process(self,
                  d_tokens: dict) -> MappingResultDict:
-        mapping_results = []
-
-        sw = Stopwatch()
 
         d_transform = d_tokens['transform']  # has token:canon mapping
         d_input = d_tokens['input']  # just text tokens
